

% DIO02 - OCTAL DIGITAL I/O DEVICE 1.0.1


% Class DIO02
classdef DIO02 < Device

   % Public static Constants
   properties (Constant)

      % Channels
      CHANNELS = 8;

      % Directions
      DIRECTION_INPUT = false;
      DIRECTION_OUTPUT = true;

   end


   % Public Member Methods
   methods

      % Constructor
      function this = DIO02(address)

         % Initialize
         this = this@Device(address);

      end


      % Set Direction
      function direction(this, varargin)

         % Check Parameters
         if nargin == 2

            % Set Channel List and Direction List
            channel = 1 : this.CHANNELS;
            direction = repmat(varargin{1}, 1, this.CHANNELS);

         elseif nargin == 3

            % Set Channel and Direction
            channel = varargin{1};
            direction = varargin{2};

            % Check Parameter
            if isscalar(direction)

               % Set Direction List
               direction = repmat(direction, 1, numel(channel));

            end

         else

            % Error Handler
            this.error_(this.ERROR_PARAMETER_);

         end

         % Set Direction
         code = calllib('device', 'dio02_set_direction', this.address_, channel, numel(channel), direction, ...
             numel(direction));

         % Error Handler
         this.error_(code);

      end


      % Read
      function state = read(this, channel)

         % Check Parameters
         if nargin == 1

            % Set Channel List
            channel = 1 : this.CHANNELS;

         end

         % Read
         [code, ~, state] = calllib('device', 'dio02_read', this.address_, channel, numel(channel), ...
             zeros(1, numel(channel)), numel(channel));

         % Error Handler
         this.error_(code);

      end


      % Write
      function write(this, varargin)

         % Check Parameters
         if nargin == 2

            % Set Channel List and State List
            channel = 1 : this.CHANNELS;
            state = repmat(varargin{1}, 1, this.CHANNELS);

         elseif nargin == 3

            % Set Channel and State
            channel = varargin{1};
            state = varargin{2};

            % Check Parameter
            if isscalar(state)

               % Set State List
               state = repmat(state, 1, numel(channel));

            end

         else

            % Error Handler
            this.error_(this.ERROR_PARAMETER_);

         end

         % Write
         code = calllib('device', 'dio02_write', this.address_, channel, numel(channel), state, numel(state));

         % Error Handler
         this.error_(code);

      end

   end

end
